@@ -1,4 +1,4 @@
 from eightest.runner import Runner
-from eightest.logger import S_Logger
+from eightest.logger import eLogger
 from eightest.testcase import TestCase
 from eightest.decorators import SMOKE_TEST, REGRESSION_TEST
