@@ -1,9 +1,12 @@
 import os
+import pathlib
 import multiprocess
 
 from datetime import datetime
 
-DOTENV_PATH = os.path.join(os.getcwd(), 'config.env')
+ROOT_DIR = pathlib.Path(__file__).resolve().parent.parent
+
+DOTENV_PATH = os.path.join(ROOT_DIR, 'config.env')
 env = os.environ
 
 
@@ -17,8 +20,12 @@ def set_cpu_count() -> None:
 
 
 def load_env_file(override=False) -> None:
-    with open(DOTENV_PATH) as file_obj:
-        lines = file_obj.read().splitlines()
+    try:
+        with open(DOTENV_PATH) as file_obj:
+            lines = file_obj.read().splitlines()
+
+    except FileNotFoundError:
+        raise FileNotFoundError('Could not config.env file.')
 
     dotenv_vars = {}
     for line in lines:
@@ -27,12 +34,10 @@ def load_env_file(override=False) -> None:
             continue
 
         key, value = line.split("=", maxsplit=1)
-        dotenv_vars.setdefault(key, value)
+        dotenv_vars.setdefault(key.strip(), value.strip())
 
     if override:
         env.update(dotenv_vars)
     else:
         for key, value in dotenv_vars.items():
             env.setdefault(key, value)
-
-    set_cpu_count()
